# colnade_pandas

Pandas backend adapter, I/O functions, and dtype mapping.

## PandasBackend

::: colnade_pandas.adapter.PandasBackend

## Construction Functions

::: colnade_pandas.io.from_dict

::: colnade_pandas.io.from_rows

## I/O Functions

::: colnade_pandas.io.read_parquet

::: colnade_pandas.io.read_csv

::: colnade_pandas.io.write_parquet

::: colnade_pandas.io.write_csv

## Dtype Mapping

::: colnade_pandas.conversion.map_colnade_dtype

::: colnade_pandas.conversion.map_pandas_dtype
